@@ -905,7 +905,7 @@ sub localizer
     if(@_)
     {
       $invocant->{'localizer'} = shift;
-      
+
       if(ref $invocant->{'localizer'} eq 'CODE')
       {
         return $invocant->{'localizer'}->();
@@ -967,7 +967,7 @@ sub locale
     if(@_)
     {
       $invocant->{'locale'} = shift;
-      
+
       if(ref $invocant->{'locale'} eq 'CODE')
       {
         return $invocant->{'locale'}->();
@@ -1007,7 +1007,7 @@ sub locale
       {
         return $locale->();
       }
-    
+
       return $locale || $class->default_locale;
     }
   }
@@ -1541,16 +1541,20 @@ This method is part of the L<Rose::HTML::Object> API.  In this case, it simply c
 
 Any L<Rose::HTML::Objects> questions or problems can be posted to the L<Rose::HTML::Objects> mailing list.  To subscribe to the list or view the archives, go here:
 
-L<http://lists.sourceforge.net/lists/listinfo/rose-html-objects>
+L<http://groups.google.com/group/rose-html-objects>
 
 Although the mailing list is the preferred support mechanism, you can also email the author (see below) or file bugs using the CPAN bug tracking system:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
 
+There's also a wiki and other resources linked from the Rose project home page:
+
+L<http://rose.googlecode.com>
+
 =head1 AUTHOR
 
 John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2008 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
