@@ -143,7 +143,7 @@ Get or set a boolean value that indicates whether or not this checkbox will be s
 
 =item B<hide>
 
-Class L<hidden|/hidden>, passing a true value.
+Calls L<hidden|/hidden>, passing a true value.
 
 =item B<html_checkbox>
 
@@ -159,7 +159,7 @@ Simply calls L<is_checked|/is_checked>.  This method exists for API uniformity b
 
 =item B<show>
 
-Class L<hidden|/hidden>, passing a false value.
+Calls L<hidden|/hidden>, passing a false value.
 
 =item B<value [VALUE]>
 
@@ -177,4 +177,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2008 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
