@@ -10,7 +10,7 @@ use Rose::HTML::Object::Message::Localizer;
 use Rose::HTML::Object::Localized;
 our @ISA = qw(Rose::HTML::Object::Localized);
 
-our $VERSION = '0.549';
+our $VERSION = '0.550';
 
 our $Debug = undef;
 
@@ -36,6 +36,7 @@ use Rose::Class::MakeMethods::Generic
     'html_element',  # may be read-only in subclasses
     'xhtml_element', # may be read-only in subclasses
     'autoload_html_attr_methods',
+    'force_utf8',
   ],
 );
 
@@ -1106,16 +1107,20 @@ Examples:
 
 Any L<Rose::HTML::Objects> questions or problems can be posted to the L<Rose::HTML::Objects> mailing list.  To subscribe to the list or view the archives, go here:
 
-L<http://lists.sourceforge.net/lists/listinfo/rose-html-objects>
+L<http://groups.google.com/group/rose-html-objects>
 
 Although the mailing list is the preferred support mechanism, you can also email the author (see below) or file bugs using the CPAN bug tracking system:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
 
+There's also a wiki and other resources linked from the Rose project home page:
+
+L<http://rose.googlecode.com>
+
 =head1 AUTHOR
 
 John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2008 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
