@@ -3,7 +3,7 @@ package Rose::HTML::Objects;
 use strict;
 
 # The sole purpose of this module is to provide a version number
-our $VERSION = '0.5521';
+our $VERSION = '0.553';
 
 1;
 
@@ -55,12 +55,16 @@ The L<Rose development policy|Rose/"DEVELOPMENT POLICY"> applies to this, and al
 
 Any L<Rose::HTML::Objects> questions or problems can be posted to the L<Rose::HTML::Objects> mailing list.  To subscribe to the list or view the archives, go here:
 
-L<http://lists.sourceforge.net/lists/listinfo/rose-html-objects>
+L<http://groups.google.com/group/rose-html-objects>
 
 Although the mailing list is the preferred support mechanism, you can also email the author (see below) or file bugs using the CPAN bug tracking system:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Rose-HTML-Objects>
 
+There's also a wiki and other resources linked from the Rose project home page:
+
+L<http://rose.googlecode.com>
+
 =head1 CONTRIBUTORS
 
 Uwe Voelker, Jacques Supcik, Cees Hek, Denis Moskowitz 
@@ -71,4 +75,4 @@ John C. Siracusa (siracusa@gmail.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+Copyright (c) 2008 by John C. Siracusa.  All rights reserved.  This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
